Learn R Programming

sirt (version 2.4-20)

sirt-utilities: Utility Functions in sirt

Description

Utility functions in sirt.

Usage

# bounds entries in a vector
bounds_parameters( pars , lower = NULL , upper = NULL)
	
# improper density function which always returns a value of 1
dimproper(x)

# generalized inverse of a symmetric function ginverse_sym(A, eps= 1E-8)

# hard thresholding function hard_thresholding(x, lambda)

# soft thresholding function soft_thresholding(x, lambda) # power function x^a, like in Cpp pow(x, a)

# trace of a matrix tracemat(A)

# plyr::rbind.fill implementation in sirt sirt_rbind_fill(x, y)

# Fisher-z transformation, see psych::fisherz sirt_fisherz(rho) # inverse Fisher-z transformation, see psych::fisherz2r sirt_antifisherz(z)

# attach all elements in a list in a specified environment sirt_attach_list_elements(x, envir)

# print objects in a summary sirt_summary_print_objects(obji, from=NULL, to=NULL, digits=3, rownames_null=TRUE) # print package version and R session sirt_summary_print_package_rsession(pack) # print package version sirt_summary_print_package(pack) # print R session sirt_summary_print_rsession() # print call sirt_summary_print_call(CALL)

Arguments

pars

Numeric vector

lower

Numeric vector

upper

Numeric vector

x

Numeric vector or a matrix or a list

eps

Numerical. Shrinkage parameter of eigenvalue in ginverse_sym

a

Numeric vector

lambda

Numeric value

A

Matrix

y

Matrix

rho

Numeric

z

Numeric

envir

Environment

obji

Data frame

from

Integer

to

Integer

digits

Integer

rownames_null

Logical

pack

Package name

CALL

Call statement

Examples

Run this code
# NOT RUN {
#############################################################################
## EXAMPLE 1: Trace of a matrix
#############################################################################	

set.seed(86)
A <- matrix( stats::runif(4) , 2 ,2 )
tracemat(A)
sum(diag(A))	# = sirt::tracemat(A)

#############################################################################
## EXAMPLE 2: Power function
#############################################################################

x <- 2.3
a <- 1.7
pow(x=x,a=a)
x^a			# = sirt::pow(x,a)

#############################################################################
## EXAMPLE 3: Soft and hard thresholding function (e.g. in LASSO estimation)
#############################################################################

x <- seq( -2 , 2 , length=100 )
y <- sirt::soft_thresholding( x , lambda = .5)
graphics::plot( x , y , type="l")

z <- sirt::hard_thresholding( x , lambda = .5)
graphics::lines( x , z , lty=2 , col=2)

#############################################################################
## EXAMPLE 4: Bounds on parameters
#############################################################################

pars <- c( .721 , .346 )
bounds_parameters( pars = pars , lower=c(-Inf, .5) , upper = c(Inf,1) )
# }

Run the code above in your browser using DataLab