rasch.mml2and the argumentitemtype="raschtype".
This model also allows the estimation of the 4PL item
response model (Loken & Rulison, 2010).
Multiple group estimation, latent regression models and
plausible value imputation are supported. In addition, pseudo-likelihood
estimation for fractional item response data can be conducted.
%% M-dim noncompensatory and compensatory IRT modelsmirtfunction and the optionsirtmodel="noncomp",irtmodel="comp"andirtmodel="partcomp".
%% 1-dim Ramsay type modelrasch.mml2withitemtype="ramsay.qm".
%% 1-dim nonparametric IRT modelsrasch.mml2withitemtype="npirt".
Kernel smoothing for item response function estimation (Ramsay, 1991)
is implemented innp.dich.
%% 1-dim Copula modelrasch.copula3.
%% 1-dim JMLrasch.jmlfunction. Bias correction methods
for item parameters are included inrasch.jml.jackknife1andrasch.jml.biascorr.
%% M-dim LC Rasch modelrasch.mirtlc.
%% Rater Modelsrm.facets. A hierarchical rater model based on
signal detection theory (DeCarlo, Kim & Johnson, 2011) can be conducted
withrm.sdt. A simple latent class model for two exchangeable
raters is implemented inlc.2raters.
%% Grade of membership modelgom.em.
%% MCMC estimation multilevel IRT modelsmcmc.2pno.ml.
%% 1-dim PCMLrasch.pairwiseorrasch.pairwise.itemcluster.
%% 1-dim PMMLrasch.pml3. In this function
local dependence can be handled by imposing residual error structure
or omitting item pairs within a dependent item cluster from the
estimation.
The functionrasch.evm.pcmestimates the mutiple group
partial credit model based on the pairwise eigenvector approach
which avoids iterative estimation.
%% MCMC estimation of some modelsmcmc.2pnothe two-parameter normal ogive model can be estimated. A hierarchical
version of this model (Janssen, Tuerlinckx, Meulders & de Boeck, 2000)
is implemented inmcmc.2pnoh. The 3PNO testlet model
(Wainer, Bradlow & Wang, 2007; Glas, 2012) can be estimated withmcmc.3pno.testlet.
Some hierarchical IRT models and random item models
(van den Noortgate, de Boeck & Meulders, 2003) can be estimated
withmcmc.2pno.ml.
%% NOHARMR2noharmruns NOHARM from withinR. Note that NOHARM must be
downloaded fromnoharm.sirt.
%% Nonparametric item response theory / ISOP modelisop.dichorisop.poly.
Item scoring within this theory can be conducted withisop.scoring.
%% Functional unidimensional item response modelf1d.irt.
%% 1-dim Rasch model variational approximationrasch.va.
%% 1-dim Guttman modelprob.guttman.
%% jackknife WLEwle.rasch.jackknife.
%% reliabilitygreenyang.reliabilityand the
marginal true score method of Dimitrov (2003) using the functionmarginal.truescore.reliability.
%% DETECTconf.detect.
%% linking / alignmentlinking.haberman. See alsoequating.raschandlinking.robust.
The alignment procedure (Asparouhov & Muthen, 2013)invariance.alignmentis originally for comfirmatory factor
analysis and aims at obtaining approximate invariance.
%% Person Fitpersonfit.stat.
%% LSDMlsdm.MCMCirt functions
therein).
See Rusch, Mair and Hatzinger (2013) and Uenlue and Yanagida (2011)
for reviews of psychometrics packages in R.##
## |-----------------------------------------------------------------|
## | sirt 0.40-4 (2013-11-26) |
## | Supplementary Item Response Theory |
## | Maintainer: Alexander Robitzsch <a.robitzsch at bifie.at > |
## | https://sites.google.com/site/alexanderrobitzsch/software |
## |-----------------------------------------------------------------|
##
## _/ _/
## _/_/_/ _/ _/_/ _/_/_/_/
## _/_/ _/ _/_/ _/
## _/_/ _/ _/ _/
## _/_/_/ _/ _/ _/_/
##Run the code above in your browser using DataLab